<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Annuler</translation>
    </message>
</context>
<context>
    <name>QAccel</name>
    <message>
        <source>Space</source>
        <translation>Espace</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Échap</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>Backtab</source>
        <translation>Tab arr</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Effacement</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Retour</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Entrée</translation>
    </message>
    <message>
        <source>Ins</source>
        <translation>Inser</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Suppr</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprim</translation>
    </message>
    <message>
        <source>SysReq</source>
        <translation>Syst</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Début</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Haut</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Bas</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>Page préc</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>Page suiv</translation>
    </message>
    <message>
        <source>CapsLock</source>
        <translation>Verr maj</translation>
    </message>
    <message>
        <source>NumLock</source>
        <translation>Verr num</translation>
    </message>
    <message>
        <source>ScrollLock</source>
        <translation>Arrêt défil</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Shift</source>
        <translation>Maj</translation>
    </message>
    <message>
        <source>F%1</source>
        <translation>F%1</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Précédent (historique)</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Successeur (historique)</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Rafraîchir</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Volume bas</translation>
    </message>
    <message>
        <source>Volume Mute</source>
        <translation>Volume muet</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Volume haut
</translation>
    </message>
    <message>
        <source>Bass Boost</source>
        <translation>Bass boost</translation>
    </message>
    <message>
        <source>Bass Up</source>
        <translation>Bass haut
</translation>
    </message>
    <message>
        <source>Bass Down</source>
        <translation>Bass bas</translation>
    </message>
    <message>
        <source>Treble Up</source>
        <translation>Tremble haut</translation>
    </message>
    <message>
        <source>Treble Down</source>
        <translation>Tremble bas</translation>
    </message>
    <message>
        <source>Media Play</source>
        <translation>Média démarrer</translation>
    </message>
    <message>
        <source>Media Stop</source>
        <translation>Média arrêt</translation>
    </message>
    <message>
        <source>Media Previous</source>
        <translation>Média précédent</translation>
    </message>
    <message>
        <source>Media Next</source>
        <translation>Média suivant</translation>
    </message>
    <message>
        <source>Media Record</source>
        <translation>Média enregistrer</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Préférés</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Recherche</translation>
    </message>
    <message>
        <source>Standby</source>
        <translation>Attente</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Ouvrir URL</translation>
    </message>
    <message>
        <source>Launch Mail</source>
        <translation>Lancer courrier</translation>
    </message>
    <message>
        <source>Launch Media</source>
        <translation>Lancer média</translation>
    </message>
    <message>
        <source>Launch (0)</source>
        <translation>Lancer (0)</translation>
    </message>
    <message>
        <source>Launch (1)</source>
        <translation>Lancer (1)</translation>
    </message>
    <message>
        <source>Launch (2)</source>
        <translation>Lancer (2)</translation>
    </message>
    <message>
        <source>Launch (3)</source>
        <translation>Lancer (3)</translation>
    </message>
    <message>
        <source>Launch (4)</source>
        <translation>Lancer (4)</translation>
    </message>
    <message>
        <source>Launch (5)</source>
        <translation>Lancer (5)</translation>
    </message>
    <message>
        <source>Launch (6)</source>
        <translation>Lancer (6)</translation>
    </message>
    <message>
        <source>Launch (7)</source>
        <translation>Lancer (7)</translation>
    </message>
    <message>
        <source>Launch (8)</source>
        <translation>Lancer (8)</translation>
    </message>
    <message>
        <source>Launch (9)</source>
        <translation>Lancer (9)</translation>
    </message>
    <message>
        <source>Launch (A)</source>
        <translation>Lancer (A)</translation>
    </message>
    <message>
        <source>Launch (B)</source>
        <translation>Lancer (B)</translation>
    </message>
    <message>
        <source>Launch (C)</source>
        <translation>Lancer (C)</translation>
    </message>
    <message>
        <source>Launch (D)</source>
        <translation>Lancer (D)</translation>
    </message>
    <message>
        <source>Launch (E)</source>
        <translation>Lancer (E)</translation>
    </message>
    <message>
        <source>Launch (F)</source>
        <translation>Lancer (F)</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Méta</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>QT_LAYOUT_DIRECTION</source>
        <comment>Translate this string to the string &apos;LTR&apos; in left-to-right languages or to &apos;RTL&apos; in right-to-left languages (such as Hebrew and Arabic) to get proper widget layout.</comment>
        <translation>LTR</translation>
    </message>
    <message>
        <source>Executable &apos;%1&apos; requires Qt %2, found Qt %3.</source>
        <translation>L&apos;exécutable &apos;%1&apos; requiert Qt %2 (Qt %3 présent).</translation>
    </message>
    <message>
        <source>Incompatible Qt Library Error</source>
        <translation>Erreur: bibliothèque Qt incompatible</translation>
    </message>
</context>
<context>
    <name>QAquaStyle</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>QColorDialog</name>
    <message>
        <source>Hu&amp;e:</source>
        <translation>&amp;Teinte :</translation>
    </message>
    <message>
        <source>&amp;Sat:</source>
        <translation>&amp;Saturation :</translation>
    </message>
    <message>
        <source>&amp;Val:</source>
        <translation>&amp;Luminance :</translation>
    </message>
    <message>
        <source>&amp;Red:</source>
        <translation>&amp;Rouge :</translation>
    </message>
    <message>
        <source>&amp;Green:</source>
        <translation>&amp;Vert :</translation>
    </message>
    <message>
        <source>Bl&amp;ue:</source>
        <translation>Ble&amp;u :</translation>
    </message>
    <message>
        <source>A&amp;lpha channel:</source>
        <translation>Canal a&amp;lpha :</translation>
    </message>
    <message>
        <source>&amp;Basic colors</source>
        <translation>Couleurs de &amp;base</translation>
    </message>
    <message>
        <source>&amp;Custom colors</source>
        <translation>&amp;Couleurs personnalisées</translation>
    </message>
    <message>
        <source>&amp;Define Custom Colors &gt;&gt;</source>
        <translation>Définir des &amp;couleurs personnalisées &gt;&gt;</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>&amp;Add to Custom Colors</source>
        <translation>&amp;Ajouter aux couleurs personnalisées</translation>
    </message>
    <message>
        <source>Select color</source>
        <translation>Sélection d&apos;une couleur</translation>
    </message>
</context>
<context>
    <name>QDataManager</name>
    <message>
        <source>Delete this record?</source>
        <translation type="obsolete">Supprimer cet enregistrement ?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">Non</translation>
    </message>
    <message>
        <source>Save edits?</source>
        <translation type="obsolete">Enregistrer les modifications ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Annuler</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="obsolete">Confirmer</translation>
    </message>
    <message>
        <source>Cancel your edits?</source>
        <translation type="obsolete">Annuler vos modifications ?</translation>
    </message>
</context>
<context>
    <name>QDataTable</name>
    <message>
        <source>True</source>
        <translation>Vrai</translation>
    </message>
    <message>
        <source>False</source>
        <translation>Faux</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insérer</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualiser</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>QDialog</name>
    <message>
        <source>What&apos;s This?</source>
        <translation>Qu&apos;est-ce que c&apos;est ?</translation>
    </message>
</context>
<context>
    <name>QErrorMessage</name>
    <message>
        <source>&amp;Show this message again</source>
        <translation>&amp;Afficher ce message de nouveau</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Debug Message:</source>
        <translation>Message de débogage:</translation>
    </message>
    <message>
        <source>Warning:</source>
        <translation>Avertissement:</translation>
    </message>
    <message>
        <source>Fatal Error:</source>
        <translation>Erreur fatale:</translation>
    </message>
</context>
<context>
    <name>QFileDialog</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>Attributes</source>
        <translation>Attributs</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Look &amp;in:</source>
        <translation>Chercher &amp;dans :</translation>
    </message>
    <message>
        <source>File &amp;name:</source>
        <translation>&amp;Nom de fichier :</translation>
    </message>
    <message>
        <source>File &amp;type:</source>
        <translation>&amp;Type de fichier :</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Précédent (historique)</translation>
    </message>
    <message>
        <source>One directory up</source>
        <translation>Aller au dossier parent</translation>
    </message>
    <message>
        <source>Create New Folder</source>
        <translation>Créer un nouveau dossier</translation>
    </message>
    <message>
        <source>List View</source>
        <translation>Affichage liste</translation>
    </message>
    <message>
        <source>Detail View</source>
        <translation>Affichage détaillé</translation>
    </message>
    <message>
        <source>Preview File Info</source>
        <translation>Informations du fichier prévisualisé</translation>
    </message>
    <message>
        <source>Preview File Contents</source>
        <translation>Contenu du fichier prévisualisé</translation>
    </message>
    <message>
        <source>Read-write</source>
        <translation>Lecture-écriture</translation>
    </message>
    <message>
        <source>Read-only</source>
        <translation>Lecture seule</translation>
    </message>
    <message>
        <source>Write-only</source>
        <translation>Écriture seule</translation>
    </message>
    <message>
        <source>Inaccessible</source>
        <translation>Inaccessible</translation>
    </message>
    <message>
        <source>Symlink to File</source>
        <translation>Lien symbolique vers un fichier</translation>
    </message>
    <message>
        <source>Symlink to Directory</source>
        <translation>Lien symbolique vers un dossier</translation>
    </message>
    <message>
        <source>Symlink to Special</source>
        <translation>Lien symbolique vers un fichier spécial</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <source>Dir</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <source>Special</source>
        <translation>Fichier spécial</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Enregistrer sous</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ouvrir</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Renommer</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Suppri&amp;mer</translation>
    </message>
    <message>
        <source>R&amp;eload</source>
        <translation>R&amp;echarger</translation>
    </message>
    <message>
        <source>Sort by &amp;Name</source>
        <translation>Trier par &amp;nom</translation>
    </message>
    <message>
        <source>Sort by &amp;Size</source>
        <translation>Trier par ta&amp;ille</translation>
    </message>
    <message>
        <source>Sort by &amp;Date</source>
        <translation>Trier par &amp;date</translation>
    </message>
    <message>
        <source>&amp;Unsorted</source>
        <translation>&amp;Non trié</translation>
    </message>
    <message>
        <source>Sort</source>
        <translation>Tri</translation>
    </message>
    <message>
        <source>Show &amp;hidden files</source>
        <translation>Afficher les fic&amp;hiers cachés</translation>
    </message>
    <message>
        <source>the file</source>
        <translation>le fichier</translation>
    </message>
    <message>
        <source>the directory</source>
        <translation>le dossier</translation>
    </message>
    <message>
        <source>the symlink</source>
        <translation>le lien symbolique</translation>
    </message>
    <message>
        <source>Delete %1</source>
        <translation>Supprimer %1</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Are you sure you wish to delete %1 &quot;%2&quot;?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Voulez-vous vraiment supprimer %1 &quot;%2&quot;?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Oui</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Non</translation>
    </message>
    <message>
        <source>New Folder 1</source>
        <translation>Nouveau dossier 1</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nouveau dossier</translation>
    </message>
    <message>
        <source>New Folder %1</source>
        <translation>Nouveau dossier %1</translation>
    </message>
    <message>
        <source>Find Directory</source>
        <translation>Chercher dans le dossier</translation>
    </message>
    <message>
        <source>Directories</source>
        <translation>Dossiers</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>%1
File not found.
Check path and filename.</source>
        <translation>%1
Impossible de trouver le fichier.
Vérifier le chemin et le nom du fichier.</translation>
    </message>
    <message>
        <source>All Files (*.*)</source>
        <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tous les fichiers (*)</translation>
    </message>
    <message>
        <source>Open </source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Select a Directory</source>
        <translation>Sélectionner un dossier</translation>
    </message>
    <message>
        <source>Copy or Move a File</source>
        <translation>Copie ou déplace un fichier</translation>
    </message>
    <message>
        <source>Read: %1</source>
        <translation>Lecture : %1</translation>
    </message>
    <message>
        <source>Write: %1</source>
        <translation>Écriture : %1</translation>
    </message>
    <message>
        <source>Directory:</source>
        <translation>Dossier:</translation>
    </message>
</context>
<context>
    <name>QFont</name>
    <message>
        <source>Latin</source>
        <translation>Latin</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Grec</translation>
    </message>
    <message>
        <source>Cyrillic</source>
        <translation>Cyrillique</translation>
    </message>
    <message>
        <source>Armenian</source>
        <translation>Arménien</translation>
    </message>
    <message>
        <source>Georgian</source>
        <translation>Géorgien</translation>
    </message>
    <message>
        <source>Runic</source>
        <translation>Runique</translation>
    </message>
    <message>
        <source>Ogham</source>
        <translation>Ogham</translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation>Hébreu</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Arabe</translation>
    </message>
    <message>
        <source>Syriac</source>
        <translation>Syriac</translation>
    </message>
    <message>
        <source>Thaana</source>
        <translation>Thaana</translation>
    </message>
    <message>
        <source>Devanagari</source>
        <translation>Devanagari</translation>
    </message>
    <message>
        <source>Bengali</source>
        <translation>Bengali</translation>
    </message>
    <message>
        <source>Gurmukhi</source>
        <translation>Gurmukhi</translation>
    </message>
    <message>
        <source>Gujarati</source>
        <translation>Gujarati</translation>
    </message>
    <message>
        <source>Oriya</source>
        <translation>Oriya</translation>
    </message>
    <message>
        <source>Tamil</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <source>Telugu</source>
        <translation>Telugu</translation>
    </message>
    <message>
        <source>Kannada</source>
        <translation>Kannada</translation>
    </message>
    <message>
        <source>Malayalam</source>
        <translation>Malayalam</translation>
    </message>
    <message>
        <source>Sinhala</source>
        <translation>Sinhala</translation>
    </message>
    <message>
        <source>Thai</source>
        <translation>Thai</translation>
    </message>
    <message>
        <source>Lao</source>
        <translation>Lao</translation>
    </message>
    <message>
        <source>Tibetan</source>
        <translation>Tibétain</translation>
    </message>
    <message>
        <source>Myanmar</source>
        <translation>Myanmar</translation>
    </message>
    <message>
        <source>Khmer</source>
        <translation>Khmer</translation>
    </message>
    <message>
        <source>Han</source>
        <translation>Han</translation>
    </message>
    <message>
        <source>Hiragana</source>
        <translation>Hiragana</translation>
    </message>
    <message>
        <source>Katakana</source>
        <translation>Katakana</translation>
    </message>
    <message>
        <source>Hangul</source>
        <translation>Hangul</translation>
    </message>
    <message>
        <source>Bopomofo</source>
        <translation>Bopomofo</translation>
    </message>
    <message>
        <source>Yi</source>
        <translation>Yi</translation>
    </message>
    <message>
        <source>Ethiopic</source>
        <translation>Éthiopique</translation>
    </message>
    <message>
        <source>Cherokee</source>
        <translation>Cherokee</translation>
    </message>
    <message>
        <source>Canadian Aboriginal</source>
        <translation>Autochtone canadien</translation>
    </message>
    <message>
        <source>Mongolian</source>
        <translation>Mongol</translation>
    </message>
    <message>
        <source>Currency Symbols</source>
        <translation>Symboles monétaires</translation>
    </message>
    <message>
        <source>Letterlike Symbols</source>
        <translation>Symboles semblables aux lettres</translation>
    </message>
    <message>
        <source>Number Forms</source>
        <translation>Formes de nombres</translation>
    </message>
    <message>
        <source>Mathematical Operators</source>
        <translation>Opérateurs mathématiques</translation>
    </message>
    <message>
        <source>Technical Symbols</source>
        <translation>Symboles techniques</translation>
    </message>
    <message>
        <source>Geometric Symbols</source>
        <translation>Symboles géométriques</translation>
    </message>
    <message>
        <source>Miscellaneous Symbols</source>
        <translation>Symboles divers</translation>
    </message>
    <message>
        <source>Enclosed and Square</source>
        <translation>Entourés et carrés</translation>
    </message>
    <message>
        <source>Braille</source>
        <translation>Braille</translation>
    </message>
    <message>
        <source>Unicode</source>
        <translation>Unicode</translation>
    </message>
    <message>
        <source>Reverse Oblique</source>
        <translation type="obsolete">Oblique inversé</translation>
    </message>
    <message>
        <source>Reverse Italic</source>
        <translation type="obsolete">Italique inversé</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="obsolete">Autre</translation>
    </message>
    <message>
        <source>Oblique</source>
        <translation type="obsolete">Oblique</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="obsolete">Italique</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="obsolete">Normal</translation>
    </message>
</context>
<context>
    <name>QFontDialog</name>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Police</translation>
    </message>
    <message>
        <source>Font st&amp;yle</source>
        <translation>St&amp;yle de police</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Taille</translation>
    </message>
    <message>
        <source>Effects</source>
        <translation>Effets</translation>
    </message>
    <message>
        <source>Stri&amp;keout</source>
        <translation>&amp;Barré</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Souligné</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation>&amp;Couleur</translation>
    </message>
    <message>
        <source>Sample</source>
        <translation>Exemple</translation>
    </message>
    <message>
        <source>Scr&amp;ipt</source>
        <translation>Scr&amp;ipt</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Select Font</source>
        <translation>Choisir une police</translation>
    </message>
</context>
<context>
    <name>QFtp</name>
    <message>
        <source>Host %1 found</source>
        <translation>Hôte %1 trouvé</translation>
    </message>
    <message>
        <source>Host found</source>
        <translation>Hôte trouvé</translation>
    </message>
    <message>
        <source>Connected to host %1</source>
        <translation>Connecté à l&apos;hôte %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Connecté à l&apos;hôte</translation>
    </message>
    <message>
        <source>Connection to %1 closed</source>
        <translation>Connexion à %1 arrêtée</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Connexion arrêtée</translation>
    </message>
    <message>
        <source>Login Incorrect</source>
        <translation type="obsolete">Informations de connexion incorrectes</translation>
    </message>
    <message>
        <source>Host %1 not found</source>
        <translation>Hôte %1 introuvable</translation>
    </message>
    <message>
        <source>Connection refused to host %1</source>
        <translation>Connection à l&apos;hôte %1 refusée</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <source>Connecting to host failed:
%1</source>
        <translation>Échec de la connexion à l&apos;hôte
%1</translation>
    </message>
    <message>
        <source>Login failed:
%1</source>
        <translation>Échec du login:
%1</translation>
    </message>
    <message>
        <source>Listing directory failed:
%1</source>
        <translation>Échec du listage du dossier:
%1</translation>
    </message>
    <message>
        <source>Changing directory failed:
%1</source>
        <translation>Échec du changement de dossier:
%1</translation>
    </message>
    <message>
        <source>Downloading file failed:
%1</source>
        <translation>Échec du téléchargement du fichier:
%1</translation>
    </message>
    <message>
        <source>Uploading file failed:
%1</source>
        <translation>Échec du télédéchargement:
%1</translation>
    </message>
    <message>
        <source>Removing file failed:
%1</source>
        <translation>Échec de la suppression d&apos;un fichier:
%1</translation>
    </message>
    <message>
        <source>Creating directory failed:
%1</source>
        <translation>Échec de la création d&apos;un dossier:
%1</translation>
    </message>
    <message>
        <source>Removing directory failed:
%1</source>
        <translation>Échec de la suppression d&apos;un dossier:
%1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connecté</translation>
    </message>
    <message>
        <source>Connection refused for data connection</source>
        <translation>Connexion donnée refusée</translation>
    </message>
</context>
<context>
    <name>QFtpPI</name>
    <message>
        <source>Not connected</source>
        <translation type="obsolete">Non connecté</translation>
    </message>
    <message>
        <source>Host %1 not found</source>
        <translation type="obsolete">Hôte %1 introuvable</translation>
    </message>
    <message>
        <source>Connection refused to host %1</source>
        <translation type="obsolete">Connecté à l&apos;hôte %1 refusée</translation>
    </message>
    <message>
        <source>Connected to host %1</source>
        <translation type="obsolete">Connecté à l&apos;hôte %1</translation>
    </message>
    <message>
        <source>Connection refused for data connection</source>
        <translation type="obsolete">Connexion donnée refusée</translation>
    </message>
</context>
<context>
    <name>QHeader</name>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
<context>
    <name>QHttp</name>
    <message>
        <source>Connection refused</source>
        <translation>Connexion refusée</translation>
    </message>
    <message>
        <source>Host %1 not found</source>
        <translation>Hôte %1 introuvable</translation>
    </message>
    <message>
        <source>Connection closed by %1</source>
        <translation type="obsolete">Connexion arrêtée par %1</translation>
    </message>
    <message>
        <source>Invalid HTTP reply header</source>
        <translation type="obsolete">Entête HTTP invalide</translation>
    </message>
    <message>
        <source>Wrong content length</source>
        <translation>Longueur du contenu invalide</translation>
    </message>
    <message>
        <source>HTTP request failed</source>
        <translation>Échec de la requête HTTP</translation>
    </message>
    <message>
        <source>Host %1 found</source>
        <translation>Hôte %1 trouvé</translation>
    </message>
    <message>
        <source>Host found</source>
        <translation>Hôte trouvé</translation>
    </message>
    <message>
        <source>Connected to host %1</source>
        <translation>Connecté à l&apos;hôte %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Connecté à l&apos;hôte</translation>
    </message>
    <message>
        <source>Connection to %1 closed</source>
        <translation>Connexion à %1 arrêtée</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Connexion arrêtée</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <source>Request aborted</source>
        <translation>Requête interrompue</translation>
    </message>
    <message>
        <source>No server set to connect to</source>
        <translation>Aucun serveur spécifié</translation>
    </message>
    <message>
        <source>Server closed connection unexpectedly</source>
        <translation>Connexion interrompue par le serveur</translation>
    </message>
    <message>
        <source>Invalid HTTP response header</source>
        <translation>Entête de réponse HTTP invalide</translation>
    </message>
    <message>
        <source>Invalid HTTP chunked body</source>
        <translation>Fragment HTTP invalide</translation>
    </message>
</context>
<context>
    <name>QInputDialog</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Tout sélectionner</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>A&amp;nnuler Annuler</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Co&amp;uper</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Cop&amp;ier</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Co&amp;ller</translation>
    </message>
</context>
<context>
    <name>QLocalFs</name>
    <message>
        <source>Could not rename
%1
to
%2</source>
        <translation>Impossible de renommer
%1
en
%2</translation>
    </message>
    <message>
        <source>Could not open
%1</source>
        <translation>Impossible d&apos;ouvrir
%1</translation>
    </message>
    <message>
        <source>Could not write
%1</source>
        <translation>Impossible d&apos;écrire
%1</translation>
    </message>
    <message>
        <source>Could not read directory
%1</source>
        <translation>Impossible de lire le dossier
%1</translation>
    </message>
    <message>
        <source>Could not create directory
%1</source>
        <translation>Impossible de créer le dossier
%1</translation>
    </message>
    <message>
        <source>Could not remove file or directory
%1</source>
        <translation>Impossible de supprimer le fichier ou dossier
%1</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Line up</source>
        <translation>Aligner</translation>
    </message>
    <message>
        <source>Customize...</source>
        <translation>Personnaliser...</translation>
    </message>
</context>
<context>
    <name>QMenuBar</name>
    <message>
        <source>About</source>
        <translation type="unfinished">A propos</translation>
    </message>
    <message>
        <source>Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Setting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Oui</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Non</translation>
    </message>
    <message>
        <source>&amp;Abort</source>
        <translation>&amp;Abandonner</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>&amp;Réessayer</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignorer</translation>
    </message>
    <message>
        <source>&lt;h3&gt;About Qt&lt;/h3&gt;&lt;p&gt;This application was created with Qt version %1.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h3&gt;À propos de Qt&lt;/h3&gt;&lt;p&gt;Ce programme utilise Qt version %1.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;This program uses Qt version %1.&lt;/p&gt;&lt;p&gt;Qt is a C++ toolkit for cross-platform GUI &amp;amp; application development.&lt;/p&gt;&lt;p&gt;Qt provides single-source portability across Windows 95/98/NT4/ME/2000, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, Solaris, HP-UX and many other versions of Unix with X11.&lt;br&gt;Qt is also available for embedded devices.&lt;/p&gt;&lt;p&gt;Qt is a Trolltech product. See &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; for more information.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Ce programme utilise Qt version %1.&lt;/p&gt;&lt;p&gt;Qt est une boîte à outils C++ pour le développement multi-plateforme d&apos;applications graphiques. Qt permet de porter un même code source sur Windows 95/98/NT4/ME/2000, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, Solaris, HP-UX et beaucoup d&apos;autres versions d&apos;Unix avec X11.&lt;br&gt;Qt est aussi disponible pour les systèmes embarqués.&lt;/p&gt;&lt;p&gt;Qt est un produit de Trolltech. Consultez &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; pour de plus amples renseignements.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;About Qt&lt;/h3&gt;&lt;p&gt;This program uses Qt version %1.&lt;/p&gt;&lt;p&gt;Qt is a C++ toolkit for cross-platform GUI &amp;amp; application development.&lt;/p&gt;&lt;p&gt;Qt provides single-source portability across Windows 95/98/NT4/ME/2000, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, Solaris, HP-UX and many other versions of Unix with X11.&lt;br&gt;Qt is also available for embedded devices.&lt;/p&gt;&lt;p&gt;Qt is a Trolltech product. See &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; for more information.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h3&gt;À propos de Qt&lt;/h3&gt;&lt;p&gt;Ce programme utilise Qt version %1.&lt;/p&gt;&lt;p&gt;Qt est une boîte à outils C++ pour le développement multi-plateforme d&apos;applications graphiques. Qt permet de porter un même code source sur Windows 95/98/NT4/ME/2000, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, Solaris, HP-UX et beaucoup d&apos;autres versions d&apos;Unix avec X11.&lt;br&gt;Qt est aussi disponible pour les systèmes embarqués.&lt;/p&gt;&lt;p&gt;Qt est un produit de Trolltech. Consultez &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; pour de plus amples renseignements.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;About Qt&lt;/h3&gt;&lt;p&gt;This program uses Qt version %1.&lt;/p&gt;&lt;p&gt;Qt is a C++ toolkit for multiplatform GUI &amp;amp; application development.&lt;/p&gt;&lt;p&gt;Qt provides single-source portability across MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, and all major commercial Unix variants.&lt;br&gt;Qt is also available for embedded devices.&lt;/p&gt;&lt;p&gt;Qt is a Trolltech product. See &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; for more information.&lt;/p&gt;</source>
        <translation>&lt;h3&gt;À propos de Qt&lt;/h3&gt;&lt;p&gt;Ce programme utilise Qt version %1.&lt;/p&gt;&lt;p&gt;Qt est une boîte à outils C++ pour le développement multi-plateforme d&apos;applications graphiques. Qt permet de porter un même code source sur MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux et toutes les versions commerciales majeures.&lt;br&gt;Qt est aussi disponible pour les systèmes embarqués.&lt;/p&gt;&lt;p&gt;Qt est un produit de Trolltech. Consultez &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; pour de plus amples renseignements.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>QNetworkProtocol</name>
    <message>
        <source>Operation stopped by the user</source>
        <translation>Opération interrompue par l&apos;utilisateur</translation>
    </message>
</context>
<context>
    <name>QPrintDialog</name>
    <message>
        <source>locally connected</source>
        <translation>connecté en local</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>inconnu</translation>
    </message>
    <message>
        <source>Unknown Location</source>
        <translation>Emplacement inconnu</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Printer settings</source>
        <translation>Configuration de l&apos;impression</translation>
    </message>
    <message>
        <source>Print in color if available</source>
        <translation>Imprimer en couleur si possible</translation>
    </message>
    <message>
        <source>Print in grayscale</source>
        <translation>Imprimer en niveaux de gris</translation>
    </message>
    <message>
        <source>Print destination</source>
        <translation>Type d&apos;impression</translation>
    </message>
    <message>
        <source>Print to printer:</source>
        <translation>Imprimer avec l&apos;imprimante :</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Imprimante</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Hôte</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Commentaire</translation>
    </message>
    <message>
        <source>Print to file:</source>
        <translation>Imprimer dans un fichier :</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Parcourir...</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Print all</source>
        <translation>Imprimer tout</translation>
    </message>
    <message>
        <source>Print range</source>
        <translation>Imprimer la sélection</translation>
    </message>
    <message>
        <source>From page:</source>
        <translation>De la page :</translation>
    </message>
    <message>
        <source>To page:</source>
        <translation>À la page :</translation>
    </message>
    <message>
        <source>Print first page first</source>
        <translation>Imprimer d&apos;abord la première page</translation>
    </message>
    <message>
        <source>Print last page first</source>
        <translation>Imprimer d&apos;abord la dernière page</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Nombre de copies :</translation>
    </message>
    <message>
        <source>Paper format</source>
        <translation>Format du papier</translation>
    </message>
    <message>
        <source>Portrait</source>
        <translation>Portrait</translation>
    </message>
    <message>
        <source>Landscape</source>
        <translation>Paysage</translation>
    </message>
    <message>
        <source>A0 (841 x 1189 mm)</source>
        <translation>A0 (841 x 1189 mm)</translation>
    </message>
    <message>
        <source>A1 (594 x 841 mm)</source>
        <translation>A1 (594 x 841 mm)</translation>
    </message>
    <message>
        <source>A2 (420 x 594 mm)</source>
        <translation>A2 (420 x 594 mm)</translation>
    </message>
    <message>
        <source>A3 (297 x 420 mm)</source>
        <translation>A3 (297 x 420 mm)</translation>
    </message>
    <message>
        <source>A4 (210x297 mm, 8.26x11.7 inches)</source>
        <translation>A4 (210x297 mm, 8.26x11.7 pouces)</translation>
    </message>
    <message>
        <source>A5 (148 x 210 mm)</source>
        <translation>A5 (148 x 210 mm)</translation>
    </message>
    <message>
        <source>A6 (105 x 148 mm)</source>
        <translation>A6 (105 x 148 mm)</translation>
    </message>
    <message>
        <source>A7 (74 x 105 mm)</source>
        <translation>A7 (74 x 105 mm)</translation>
    </message>
    <message>
        <source>A8 (52 x 74 mm)</source>
        <translation>A8 (52 x 74 mm)</translation>
    </message>
    <message>
        <source>A9 (37 x 52 mm)</source>
        <translation>A9 (37 x 52 mm)</translation>
    </message>
    <message>
        <source>B0 (1000 x 1414 mm)</source>
        <translation>B0 (1000 x 1414 mm)</translation>
    </message>
    <message>
        <source>B1 (707 x 1000 mm)</source>
        <translation>B1 (707 x 1000 mm)</translation>
    </message>
    <message>
        <source>B2 (500 x 707 mm)</source>
        <translation>B2 (500 x 707 mm)</translation>
    </message>
    <message>
        <source>B3 (353 x 500 mm)</source>
        <translation>B3 (353 x 500 mm)</translation>
    </message>
    <message>
        <source>B4 (250 x 353 mm)</source>
        <translation>B4 (250 x 353 mm)</translation>
    </message>
    <message>
        <source>B5 (176 x 250 mm, 6.93x9.84 inches)</source>
        <translation>B5 (176 x 250 mm, 6.93x9.84 pouces)</translation>
    </message>
    <message>
        <source>B6 (125 x 176 mm)</source>
        <translation>B6 (125 x 176 mm)</translation>
    </message>
    <message>
        <source>B7 (88 x 125 mm)</source>
        <translation>B7 (88 x 125 mm)</translation>
    </message>
    <message>
        <source>B8 (62 x 88 mm)</source>
        <translation>B8 (62 x 88 mm)</translation>
    </message>
    <message>
        <source>B9 (44 x 62 mm)</source>
        <translation>B9 (44 x 62 mm)</translation>
    </message>
    <message>
        <source>B10 (31 x 44 mm)</source>
        <translation>B10 (31 x 44 mm)</translation>
    </message>
    <message>
        <source>C5E (163 x 229 mm)</source>
        <translation>C5E (163 x 229 mm)</translation>
    </message>
    <message>
        <source>DLE (110 x 220 mm)</source>
        <translation>DLE (110 x 220 mm)</translation>
    </message>
    <message>
        <source>Executive (7.5x10 inches, 191x254 mm)</source>
        <translation>Exécutive (7.5x10 pouces, 191x254 mm)</translation>
    </message>
    <message>
        <source>Folio (210 x 330 mm)</source>
        <translation>Folio (210 x 330 mm)</translation>
    </message>
    <message>
        <source>Ledger (432 x 279 mm)</source>
        <translation>Ledger (432 x 279 mm)</translation>
    </message>
    <message>
        <source>Legal (8.5x14 inches, 216x356 mm)</source>
        <translation>Légal (8.5x14 pouces, 216x356 mm)</translation>
    </message>
    <message>
        <source>Letter (8.5x11 inches, 216x279 mm)</source>
        <translation>Lettre (8.5x11 pouces, 216x279 mm)</translation>
    </message>
    <message>
        <source>Tabloid (279 x 432 mm)</source>
        <translation>Tabloïde (279 x 432 mm)</translation>
    </message>
    <message>
        <source>US Common #10 Envelope (105 x 241 mm)</source>
        <translation>US Common #10 Envelope (105 x 241 mm)</translation>
    </message>
    <message>
        <source>Setup Printer</source>
        <translation>Configuration de l&apos;impression</translation>
    </message>
    <message>
        <source>Aliases: %1</source>
        <translation>Alias : %1</translation>
    </message>
    <message>
        <source>PostScript Files (*.ps);;All Files (*)</source>
        <translation>Fichiers PostScript (*.ps);;Tous les fichiers (*)</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>QRegExp</name>
    <message>
        <source>no error occurred</source>
        <translation>aucune erreur ne s&apos;est produite</translation>
    </message>
    <message>
        <source>disabled feature used</source>
        <translation>option désactivée</translation>
    </message>
    <message>
        <source>bad char class syntax</source>
        <translation>syntaxe invalide pour classe de caractère</translation>
    </message>
    <message>
        <source>bad lookahead syntax</source>
        <translation>syntaxe invalide pour lookahead</translation>
    </message>
    <message>
        <source>bad repetition syntax</source>
        <translation>syntaxe invalide pour répétition</translation>
    </message>
    <message>
        <source>invalid octal value</source>
        <translation>valeur octale invalide</translation>
    </message>
    <message>
        <source>missing left delim</source>
        <translation>délémiteur gauche manquant</translation>
    </message>
    <message>
        <source>unexpected end</source>
        <translation>fin impromptue</translation>
    </message>
    <message>
        <source>met internal limit</source>
        <translation>rencontré limite interne</translation>
    </message>
</context>
<context>
    <name>QSql</name>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Delete this record?</source>
        <translation>Supprimer cet enregistrement ?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insérer</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualiser</translation>
    </message>
    <message>
        <source>Save edits?</source>
        <translation>Enregistrer les modifications ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
    <message>
        <source>Cancel your edits?</source>
        <translation>Annuler vos modifications ?</translation>
    </message>
    <message>
        <source>Could not open database connection</source>
        <translation type="obsolete">Impossible d&apos;ouvrir la connection à la base de donnéees</translation>
    </message>
    <message>
        <source>Could not open database</source>
        <translation type="obsolete">Impossible d&apos;ouvrir la base de données</translation>
    </message>
</context>
<context>
    <name>QTDSDriver</name>
    <message>
        <source>Could not open database connection</source>
        <translation type="obsolete">Impossible d&apos;ouvrir la connection à la base de donnéees</translation>
    </message>
    <message>
        <source>Could not open database</source>
        <translation type="obsolete">Impossible d&apos;ouvrir la base de données</translation>
    </message>
</context>
<context>
    <name>QTabDialog</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>QTextEdit</name>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Tout sélectionner</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>A&amp;nnuler Annuler</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Co&amp;uper</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Cop&amp;ier</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Co&amp;ller</translation>
    </message>
</context>
<context>
    <name>QTitleBar</name>
    <message>
        <source>System Menu</source>
        <translation>Menu système</translation>
    </message>
    <message>
        <source>Shade</source>
        <translation>Enrouler</translation>
    </message>
    <message>
        <source>Unshade</source>
        <translation>Dérouler</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normaliser</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Réduire</translation>
    </message>
    <message>
        <source>Maximize</source>
        <translation>Maximiser</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>QToolBar</name>
    <message>
        <source>More...</source>
        <translation>Reste...</translation>
    </message>
</context>
<context>
    <name>QUrlOperator</name>
    <message>
        <source>The protocol `%1&apos; is not supported</source>
        <translation>Le protocole &apos;%1&apos; n&apos;est pas supporté</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support listing directories</source>
        <translation>Le protocole `%1&apos; ne supporte pas le listage des fichiers d&apos;un dossier</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support creating new directories</source>
        <translation>Le protocole `%1&apos; ne supporte pas la création de nouveaux dossiers</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support removing files or directories</source>
        <translation>Le protocole `%1&apos; ne supporte pas la suppression de fichiers ou de dossiers</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support renaming files or directories</source>
        <translation>Le protocole `%1&apos; ne supporte pas le renommage de fichiers ou de dossiers</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support getting files</source>
        <translation>Le protocole `%1&apos; ne supporte pas l&apos;envoi de fichiers</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support putting files</source>
        <translation>Le protocole `%1&apos; ne supporte pas la réception de fichiers</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support copying or moving files or directories</source>
        <translation>Le protocole `%1&apos; ne supporte pas la copie ou le déplacement de fichiers ou de dossiers</translation>
    </message>
    <message>
        <source>(unknown)</source>
        <translation>(inconnu)</translation>
    </message>
</context>
<context>
    <name>QWSDecoration</name>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>KDE</source>
        <translation>KDE</translation>
    </message>
    <message>
        <source>KDE2</source>
        <translation>KDE2</translation>
    </message>
    <message>
        <source>Hydro</source>
        <translation>Hydro</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurer</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Déplacer</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Redimensionner</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Réd&amp;uire</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximiser</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>BeOS</source>
        <translation>BeOS</translation>
    </message>
</context>
<context>
    <name>QWSManager</name>
    <message>
        <source>Style</source>
        <translation type="obsolete">Style</translation>
    </message>
</context>
<context>
    <name>QWhatsThisButton</name>
    <message>
        <source>What&apos;s this?</source>
        <translation>Qu&apos;est-ce que c&apos;est ?</translation>
    </message>
</context>
<context>
    <name>QWizard</name>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Annuler</translation>
    </message>
    <message>
        <source>&lt; Back</source>
        <translation type="obsolete">&lt; Précédent</translation>
    </message>
    <message>
        <source>Next &gt;</source>
        <translation type="obsolete">Suivant &gt;</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation type="obsolete">Terminer</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="obsolete">Aide</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>&lt; &amp;Back</source>
        <translation>&lt; &amp;Précédent</translation>
    </message>
    <message>
        <source>&amp;Next &gt;</source>
        <translation>&amp;Suivant &gt;</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Terminer</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
</context>
<context>
    <name>QWorkspace</name>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurer</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Déplacer</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Redimensionner</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Réd&amp;uire</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximiser</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>Stay on &amp;Top</source>
        <translation>&amp;Rester au premier plan</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Réduire</translation>
    </message>
    <message>
        <source>Restore Down</source>
        <translation>Restaurer en bas</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Sh&amp;ade</source>
        <translation>&amp;Enrouler</translation>
    </message>
    <message>
        <source>%1 - [%2]</source>
        <translation>%1 - [%2]</translation>
    </message>
    <message>
        <source>&amp;Unshade</source>
        <translation>&amp;Dérouler</translation>
    </message>
</context>
<context>
    <name>QXml</name>
    <message>
        <source>no error occurred</source>
        <translation>aucune erreur ne s&apos;est produite</translation>
    </message>
    <message>
        <source>error triggered by consumer</source>
        <translation>erreur déclenchée par le consommateur</translation>
    </message>
    <message>
        <source>unexpected end of file</source>
        <translation>fin de fichier impromptue</translation>
    </message>
    <message>
        <source>more than one document type definition</source>
        <translation>plus d&apos;une définition de type de document</translation>
    </message>
    <message>
        <source>error occurred while parsing element</source>
        <translation>une erreur s&apos;est produite lors de l&apos;analyse d&apos;un élément</translation>
    </message>
    <message>
        <source>tag mismatch</source>
        <translation>balise débalancée</translation>
    </message>
    <message>
        <source>error occurred while parsing content</source>
        <translation>une erreur s&apos;est produise lors de l&apos;analyse du contenu</translation>
    </message>
    <message>
        <source>unexpected character</source>
        <translation>caractère impromptu</translation>
    </message>
    <message>
        <source>invalid name for processing instruction</source>
        <translation>nom d&apos;instruction de traitement invalide</translation>
    </message>
    <message>
        <source>version expected while reading the XML declaration</source>
        <translation>version attendue dans la déclaration XML</translation>
    </message>
    <message>
        <source>wrong value for standalone declaration</source>
        <translation>valeur invalide pour déclaration autonome</translation>
    </message>
    <message>
        <source>error occurred while parsing document type definition</source>
        <translation>une erreur s&apos;est produite lors de l&apos;analyse d&apos;une définition de type de document</translation>
    </message>
    <message>
        <source>letter is expected</source>
        <translation>lettre attendue</translation>
    </message>
    <message>
        <source>error occurred while parsing comment</source>
        <translation>une erreur s&apos;est produise lors de l&apos;analyse d&apos;un commentaire</translation>
    </message>
    <message>
        <source>error occurred while parsing reference</source>
        <translation>une erreur s&apos;est produite lors de l&apos;analyse d&apos;une référence</translation>
    </message>
    <message>
        <source>internal general entity reference not allowed in DTD</source>
        <translation>appel d&apos;entité interne générale non permis dans la DTD</translation>
    </message>
    <message>
        <source>external parsed general entity reference not allowed in attribute value</source>
        <translation>appel d&apos;entité externe parsée  non permis dans la valeur d&apos;un attribut</translation>
    </message>
    <message>
        <source>external parsed general entity reference not allowed in DTD</source>
        <translation>appel d&apos;entité externe parsée générale non permis dans la DTD</translation>
    </message>
    <message>
        <source>unparsed entity reference in wrong context</source>
        <translation>appel d&apos;entité non parsée dans un contexte invalide</translation>
    </message>
    <message>
        <source>recursive entities</source>
        <translation>entités récursives</translation>
    </message>
    <message>
        <source>error in the text declaration of an external entity</source>
        <translation>erreur dans la déclaration de texte d&apos;une entité externe</translation>
    </message>
    <message>
        <source>encoding declaration or standalone declaration expected while reading the XML declaration</source>
        <translation>déclaration d&apos;encodage ou déclaration autonome attendue dans la déclaration XML</translation>
    </message>
    <message>
        <source>standalone declaration expected while reading the XML declaration</source>
        <translation>déclaration autonome attendue dans la déclaration XML</translation>
    </message>
</context>
<context>
    <name>QtMultiLineEdit</name>
    <message>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Annuler Annuler</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <source>Paste special...</source>
        <translation>Collage spécial...</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Tout sélectionner</translation>
    </message>
</context>
</TS>
